@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -21,10 +22,9 @@
 
 namespace polymake { namespace graph {
 
-Array<Set<int> > calc_all_spanningtrees(const Graph<>& G)
+Array<Set<Int>> calc_all_spanningtrees(const Graph<>& G)
 {
-   Array< Set<int> > st = all_spanningtrees(G);
-   return st;
+   return all_spanningtrees(G);
 }
 
 UserFunction4perl("# @category Combinatorics"
